# pharia-studio-sdk

Formally the `intelligence_layer/core` package.

## Overview

The pharia-studio-sdk provides essential functionality for the intelligence layer. TBD

## Installation
The SDK is published on [PyPI](#).

To add the SDK as a dependency to an existing project managed, run
```bash
pip install pharia-studio-sdk
```

## Contributing

We welcome contributions! Please see our [Contributing Guide](CONTRIBUTING.md) for details on how to set up the development environment and submit changes.
